@@ -4,32 +4,13 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
-
-use File::ShareDir qw(dist_dir);
-use File::Spec;
+our $VERSION = '0.03';
 
 use parent 'Alien::Base';
 
-sub incdir {
-	my $class = shift;
-
-	return File::Spec->catdir(
-		dist_dir("Alien-PDFio"),
-		"include"
-	);
-}
-
-sub libdir {
-	my $class = shift;
-
-	return File::Spec->catdir(
-		dist_dir("Alien-PDFio"),
-		"lib"
-	);
-}
 
 1;
+
 __END__;
 
 =head1 NAME
@@ -38,7 +19,7 @@ Alien::PDFio - Alien distribution for PDFio
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
